﻿using Syncfusion.UI.Xaml.Controls.SfRibbon;
using Syncfusion.UI.Xaml.RichTextBoxAdv;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.UI;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Media;

namespace DocumentEditor_UWP
{
    public class FontFamilyRibbonComboBoxItemConverter : IValueConverter
    {
        /// <summary>
        /// Converts the specified font family value to combo boxItem.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            if (value is FontFamily)
                return (value as FontFamily).Source;
            return " ";
        }
        /// <summary>
        /// Converts the combo box item value to Font family type.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            string fontvalue = (string)(value as SfRibbonComboBoxItem).Content;
            FontFamily font = new FontFamily(fontvalue);
            if (font != null)
                return font;
            return new FontFamily("Calibri");
        }
    }

    /// <summary>
    /// Specifies the double to string converter.
    /// </summary>
    public class DoubleStringConverter : IValueConverter
    {
        /// <summary>
        /// Converts the specified double to string type.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            if ((double)value == 0)
                return "";
            //Font size is converted to Pixel to Point.
            double fontSize = ((double)value * 72 / 96);
            return (Math.Round(fontSize)).ToString();
        }
        /// <summary>
        /// Converts the specified string to double value.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            return Double.Parse((string)value);
        }
    }
    /// <summary>
    /// Specifies the highlight color to toggle value.
    /// </summary>
    public class HighlightColorToggleConverter : IValueConverter
    {
        /// <summary>
        /// Converts the specified Highlight color value to toggle.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            if (value == null || parameter == null)
                return false;
            HighlightColor highlightColor = (HighlightColor)value;
            if (parameter.ToString().Equals("Red") && highlightColor == HighlightColor.Red)
                return true;
            else if (parameter.ToString().Equals("Yellow") && highlightColor == HighlightColor.Yellow)
                return true;
            else if (parameter.ToString().Equals("Green") && highlightColor == HighlightColor.Green)
                return true;
            else
                return false;
        }
        /// <summary>
        /// Converts the toggle to Highlight color.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            string highlightColor = parameter == null ? string.Empty : parameter.ToString();
            if ((bool)value)
            {
                switch (highlightColor)
                {
                    case "Yellow": return HighlightColor.Yellow;
                    case "Red": return HighlightColor.Red;
                    case "Green": return HighlightColor.Green;
                }
            }
            return HighlightColor.NoColor;
        }
    }
    /// <summary>
    /// Specifies the highlight color to selected index converter.
    /// </summary>
    public class HighlightColorConverter : IValueConverter
    {
        /// <summary>
        /// Converts the specified Highlight color value to selected index.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object Convert(object value, Type targetType, object parameter, string language)
        {

            if (value == null)
                return -1;
            HighlightColor color = (HighlightColor)value;

            switch (color)
            {
                case HighlightColor.Yellow: return 0;
                case HighlightColor.BrightGreen: return 1;
                case HighlightColor.Turquoise: return 2;
                case HighlightColor.Pink: return 3;
                case HighlightColor.Blue: return 4;
                case HighlightColor.Red: return 5;
                case HighlightColor.DarkBlue: return 6;
                case HighlightColor.Teal: return 7;
                case HighlightColor.Green: return 8;
                case HighlightColor.Violet: return 9;
                case HighlightColor.DarkRed: return 10;
                case HighlightColor.DarkYellow: return 11;
                case HighlightColor.Gray50: return 12;
                case HighlightColor.Gray25: return 13;
                case HighlightColor.Black: return 14;
                default: return 15;
            }
        }
        /// <summary>
        /// Converts the selected index to Highlight color.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            switch ((int)value)
            {
                case 0: return HighlightColor.Yellow;
                case 1: return HighlightColor.BrightGreen;
                case 2: return HighlightColor.Turquoise;
                case 3: return HighlightColor.Pink;
                case 4: return HighlightColor.Blue;
                case 5: return HighlightColor.Red;
                case 6: return HighlightColor.DarkBlue;
                case 7: return HighlightColor.Teal;
                case 8: return HighlightColor.Green;
                case 9: return HighlightColor.Violet;
                case 10: return HighlightColor.DarkRed;
                case 11: return HighlightColor.DarkYellow;
                case 12: return HighlightColor.Gray50;
                case 13: return HighlightColor.Gray25;
                case 14: return HighlightColor.Black;
                default: return HighlightColor.NoColor;
            }
        }
    }
    /// <summary>
    /// Specifies the font color to toggle value.
    /// </summary>
    public class FontColorToggleConverter : IValueConverter
    {
        /// <summary>
        /// Converts the specified font color value to toggle.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            if (value == null || parameter == null)
                return false;
            Color fontColor = (Color)value;
            if (parameter.ToString().Equals("Red") && fontColor.R == 255 && fontColor.G == 0 && fontColor.B == 0)
                return true;
            else if (parameter.ToString().Equals("Green") && fontColor.R == 0 && fontColor.G == 176 && fontColor.B == 0)
                return true;
            else if (parameter.ToString().Equals("Orange") && fontColor.R == 227 && fontColor.G == 108 && fontColor.B == 9)
                return true;
            else
                return false;
        }
        /// <summary>
        /// Converts the toggle to Font color.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">Type of the target.</param>
        /// <param name="parameter">The parameter.</param>
        /// <param name="language">The language.</param>
        /// <returns></returns>
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            string fontColor = parameter == null ? string.Empty : parameter.ToString();
            if ((bool)value)
            {
                switch (fontColor)
                {
                    case "Orange": return Color.FromArgb(255, 227, 108, 9);
                    case "Red": return Color.FromArgb(255, 255, 0, 0);
                    case "Green": return Color.FromArgb(255, 0, 176, 0);
                }
            }
            return Color.FromArgb(255, 0, 0, 0);
        }
    }
    /// <summary>
    /// Specifies the Slected color value.
    /// </summary>
    public class SelectedColorConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            return new SolidColorBrush((Color)value);
        }
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            return value;
        }
    }
    /// <summary>
    /// Converts the Pixel to Point and vice versa.
    /// </summary>
    public class PixelToPointConverter : IValueConverter
    {
        /// <summary>
        /// Converts the Pixel value to Point.
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">The targert type.</param>
        /// <param name="parameter">The converter parameter</param>
        /// <param name="language">The language.</param>
        /// <returns>The converted Point value</returns>
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            double fontSize = (double)value;
            return (fontSize * 72) / 96 ;
        }
        /// <summary>
        /// Converts Point to Pixel. 
        /// </summary>
        /// <param name="value">The value.</param>
        /// <param name="targetType">The targert type.</param>
        /// <param name="parameter">The converter parameter</param>
        /// <param name="language">The language.</param>
        /// <returns>The converted Pixel value.</returns>
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            double fontSize = (double)value;
            return (fontSize * 96) / 72;
        }
    }


}
